@@ -33,6 +33,7 @@
 #include "creds/httpcredentialsgui.h"
 #include "tooltipupdater.h"
 #include "filesystem.h"
+#include "wizard/owncloudwizard.h"
 
 #include <math.h>
 
@@ -251,7 +252,12 @@ void AccountSettings::slotToggleSignInState()
 
 void AccountSettings::doExpand()
 {
-    ui->_folderList->expandToDepth(0);
+    // Make sure at least the root items are expanded
+    for (int i = 0; i < _model->rowCount(); ++i) {
+        auto idx = _model->index(i);
+        if (!ui->_folderList->isExpanded(idx))
+            ui->_folderList->setExpanded(idx, true);
+    }
 }
 
 void AccountSettings::slotCustomContextMenuRequested(const QPoint &pos)
@@ -306,7 +312,7 @@ void AccountSettings::slotCustomContextMenuRequested(const QPoint &pos)
 
     if (!folderPaused) {
         ac = menu->addAction(tr("Force sync now"));
-        if (folderMan->currentSyncFolder() == folderMan->folder(alias)) {
+        if (folderMan->currentSyncFolder() == folder) {
             ac->setText(tr("Restart sync"));
         }
         ac->setEnabled(folderConnected);
@@ -318,6 +324,39 @@ void AccountSettings::slotCustomContextMenuRequested(const QPoint &pos)
 
     ac = menu->addAction(tr("Remove folder sync connection"));
     connect(ac, &QAction::triggered, this, &AccountSettings::slotRemoveCurrentFolder);
+
+    if (Theme::instance()->showVirtualFilesOption() || folder->useVirtualFiles()) {
+        ac = menu->addAction(tr("Create virtual files for new files (Experimental)"));
+        ac->setCheckable(true);
+        ac->setChecked(folder->useVirtualFiles());
+        connect(ac, &QAction::toggled, this, [folder, this](bool checked) {
+            if (!checked) {
+                if (folder)
+                    folder->setUseVirtualFiles(false);
+                // Make sure the size is recomputed as the virtual file indicator changes
+                ui->_folderList->doItemsLayout();
+                return;
+            }
+            OwncloudWizard::askExperimentalVirtualFilesFeature([folder, this](bool enable) {
+                if (enable && folder)
+                    folder->setUseVirtualFiles(enable);
+
+                // Also wipe selective sync settings
+                bool ok = false;
+                auto oldBlacklist = folder->journalDb()->getSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, &ok);
+                folder->journalDb()->setSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, {});
+                for (const auto &entry : oldBlacklist) {
+                    folder->journalDb()->avoidReadFromDbOnNextSync(entry);
+                }
+                FolderMan::instance()->scheduleFolder(folder);
+
+                // Make sure the size is recomputed as the virtual file indicator changes
+                ui->_folderList->doItemsLayout();
+            });
+        });
+    }
+
+
     menu->popup(tv->mapToGlobal(pos));
 }
 
@@ -362,6 +401,7 @@ void AccountSettings::slotAddFolder()
     folderMan->setSyncEnabled(false); // do not start more syncs.
 
     FolderWizard *folderWizard = new FolderWizard(_accountState->account(), this);
+    folderWizard->setAttribute(Qt::WA_DeleteOnClose);
 
     connect(folderWizard, &QDialog::accepted, this, &AccountSettings::slotFolderWizardAccepted);
     connect(folderWizard, &QDialog::rejected, this, &AccountSettings::slotFolderWizardRejected);
