@@ -1340,7 +1340,16 @@ static QString canonicalPath(const QString &path)
 {
     QFileInfo selFile(path);
     if (!selFile.exists()) {
-        return canonicalPath(selFile.dir().path()) + '/' + selFile.fileName();
+        const auto parentPath = selFile.dir().path();
+
+        // It's possible for the parentPath to match the path
+        // (possibly we've arrived at a non-existant drive root on Windows)
+        // and recursing would be fatal.
+        if (parentPath == path) {
+            return path;
+        }
+
+        return canonicalPath(parentPath) + '/' + selFile.fileName();
     }
     return selFile.canonicalFilePath();
 }
