@@ -118,15 +118,20 @@ private:
 class SocketListener
 {
 public:
-    QIODevice *socket;
+    QPointer<QIODevice> socket;
 
-    SocketListener(QIODevice *socket = 0)
+    explicit SocketListener(QIODevice *socket)
         : socket(socket)
     {
     }
 
     void sendMessage(const QString &message, bool doWait = false) const
     {
+        if (!socket) {
+            qCInfo(lcSocketApi) << "Not sending message to dead socket:" << message;
+            return;
+        }
+
         qCInfo(lcSocketApi) << "Sending SocketAPI message -->" << message << "to" << socket;
         QString localMessage = message;
         if (!localMessage.endsWith(QLatin1Char('\n'))) {
@@ -280,7 +285,19 @@ void SocketApi::slotReadSocket()
 {
     QIODevice *socket = qobject_cast<QIODevice *>(sender());
     ASSERT(socket);
-    SocketListener *listener = &*std::find_if(_listeners.begin(), _listeners.end(), ListenerHasSocketPred(socket));
+
+    // Find the SocketListener
+    //
+    // It's possible for the disconnected() signal to be triggered before
+    // the readyRead() signals are received - in that case there won't be a
+    // valid listener. We execute the handler anyway, but it will work with
+    // a SocketListener that doesn't send any messages.
+    static auto noListener = SocketListener(nullptr);
+    SocketListener *listener = &noListener;
+    auto listenerIt = std::find_if(_listeners.begin(), _listeners.end(), ListenerHasSocketPred(socket));
+    if (listenerIt != _listeners.end()) {
+        listener = &*listenerIt;
+    }
 
     while (socket->canReadLine()) {
         // Make sure to normalize the input from the socket to
@@ -470,6 +487,7 @@ public:
     GetOrCreatePublicLinkShare(const AccountPtr &account, const QString &localFile,
         std::function<void(const QString &link)> targetFun, QObject *parent)
         : QObject(parent)
+        , _account(account)
         , _shareManager(account)
         , _localFile(localFile)
         , _targetFun(targetFun)
@@ -492,6 +510,12 @@ private slots:
     void sharesFetched(const QList<QSharedPointer<Share>> &shares)
     {
         auto shareName = SocketApi::tr("Context menu share");
+
+        // If shares will expire, create a new one every day.
+        if (_account->capabilities().sharePublicLinkDefaultExpire()) {
+            shareName = SocketApi::tr("Context menu share %1").arg(QDate::currentDate().toString(Qt::ISODate));
+        }
+
         // If there already is a context menu share, reuse it
         for (const auto &share : shares) {
             const auto linkShare = qSharedPointerDynamicCast<LinkShare>(share);
@@ -534,6 +558,7 @@ private:
         deleteLater();
     }
 
+    AccountPtr _account;
     ShareManager _shareManager;
     QString _localFile;
     std::function<void(const QString &url)> _targetFun;
@@ -648,13 +673,13 @@ void SocketApi::command_REPLACE_VIRTUAL_FILE(const QString &filesArg, SocketList
                     qCWarning(lcSocketApi) << "Unable to rename " << file;
                 }
             });
-            continue;
-        }
-        SyncJournalFileRecord record;
-        if (!folder->journalDb()->getFileRecord(relativePath, &record) || !record.isValid())
-            continue;
-        if (!FileSystem::rename(file, file + suffix)) {
-            qCWarning(lcSocketApi) << "Unable to rename " << file;
+        } else {
+            SyncJournalFileRecord record;
+            if (!folder->journalDb()->getFileRecord(relativePath, &record) || !record.isValid())
+                continue;
+            if (!FileSystem::rename(file, file + suffix)) {
+                qCWarning(lcSocketApi) << "Unable to rename " << file;
+            }
         }
         folder->slotWatchedPathChanged(file); // make sure it is in the _localDiscoveryTracker list
         FolderMan::instance()->scheduleFolder(folder);
@@ -714,7 +739,6 @@ void SocketApi::sendSharingContextMenuOptions(const FileData &fileData, SocketLi
 
         // Is is possible to create a public link without user choices?
         bool canCreateDefaultPublicLink = publicLinksEnabled
-            && !capabilities.sharePublicLinkEnforceExpireDate()
             && !capabilities.sharePublicLinkEnforcePassword();
 
         if (canCreateDefaultPublicLink) {
